<?php

namespace Reinaldo\Teste00pkg\Providers;

use Illuminate\Support\ServiceProvider;
use Reinaldo\Teste00pkg\Teste00pkgs;

class Teste00pkgServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'teste00pkg');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'teste00pkg');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Reinaldo\Teste00pkg\Providers\AuthServiceProvider::class);
        $this->app->register(\Reinaldo\Teste00pkg\Providers\RouteServiceProvider::class);
        // $this->app->register(\Reinaldo\Teste00pkg\Providers\EventServiceProvider::class);
        // $this->app->register(\Reinaldo\Teste00pkg\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('reinaldo.teste00pkg', function($app)
        {
            return $this->app->make(Teste00pkgs::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind Comercial to repository
        $this->app->bind(
            'Reinaldo\Teste00pkg\Interfaces\ComercialRepositoryInterface',
            \Reinaldo\Teste00pkg\Repositories\Eloquent\ComercialRepository::class
        );        // Bind Comercial to repository
        $this->app->bind(
            'Reinaldo\Teste00pkg\Interfaces\ComercialRepositoryInterface',
            \Reinaldo\Teste00pkg\Repositories\Eloquent\ComercialRepository::class
        );
    }


    /**
     * Merges user's and teste00pkg's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'reinaldo.teste00pkg'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Reinaldo\Teste00pkg\Commands\Teste00pkg::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['reinaldo.teste00pkg'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('reinaldo/teste00pkg.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/teste00pkg')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/teste00pkg')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
